about summary refs log tree commit diff
path: root/src/test
diff options
context:
space:
mode:
authorSimon Sapin <simon.sapin@exyr.org>2018-04-05 17:09:28 +0200
committerSimon Sapin <simon.sapin@exyr.org>2018-04-12 00:13:43 +0200
commit5807be7ccb2c14df9db87a54038221bbf5ae00fa (patch)
tree9f929cd883f06c42c62d985cad4e06c9b683a066 /src/test
parentf87d4a15a82a76e7510629173c366d084f2c02ca (diff)
downloadrust-5807be7ccb2c14df9db87a54038221bbf5ae00fa.tar.gz
rust-5807be7ccb2c14df9db87a54038221bbf5ae00fa.zip
Move contents of libstd_unicode into libcore
Diffstat (limited to 'src/test')
-rw-r--r--src/test/compile-fail/single-primitive-inherent-impl.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/test/compile-fail/single-primitive-inherent-impl.rs b/src/test/compile-fail/single-primitive-inherent-impl.rs
index 5ceb870528a..365387c3e5e 100644
--- a/src/test/compile-fail/single-primitive-inherent-impl.rs
+++ b/src/test/compile-fail/single-primitive-inherent-impl.rs
@@ -15,9 +15,9 @@
 #![no_std]
 
 // OK
-#[lang = "char"]
-impl char {}
+#[lang = "str"]
+impl str {}
 
-impl char {
-//~^ error: only a single inherent implementation marked with `#[lang = "char"]` is allowed for the `char` primitive
+impl str {
+//~^ error: only a single inherent implementation marked with `#[lang = "str"]` is allowed for the `str` primitive
 }